==================
Summary
==================

pyspectator_tornado is a web-monitoring tool ported on Tornado with pyspectator as a main monitoring module.


==================
Requirements
==================

- OS: Linux, Windows, FreeBSD, Solaris
- Python version: 3.X
- Packages: pyspectator, tornado


==================
How to install
==================

Run as root user:

.. code-block:: bash

    pip install pyspectator_tornado


==================
How to use
==================

Execute file "start.py" in a root directory of project:

.. code-block:: bash

    python start.py